@@ -55,9 +55,6 @@ static char  *fontfile = NULL;
 static char  *mode     = NULL;
 static char  *joydev   = NULL;
 static struct fs_font *f;
-#ifndef X_DISPLAY_MISSING
-static char *x11_font = "10x20";
-#endif
 
 static unsigned short red[256],  green[256],  blue[256];
 static struct fb_cmap cmap  = { 0, 256, red,  green,  blue };
@@ -238,7 +235,7 @@ fb_initcolors(int fd, int gray)
 	if (-1 == ioctl(fd,FBIOGETCMAP,&cmap))
 	    perror("ioctl FBIOGETCMAP");
     }
-    
+
     switch (fb_var.bits_per_pixel) {
     case 8:
 	if (gray) {
@@ -322,14 +319,10 @@ text_init(char *font)
     char   *fonts[2] = { font, NULL };
 
     if (NULL == f)
-        f = fs_consolefont(font ? fonts : NULL);
-#ifndef X_DISPLAY_MISSING
-    if (NULL == f && 0 == fs_connect(NULL))
-        f = fs_open(font ? font : x11_font);
-#endif
+	f = fs_consolefont(font ? fonts : NULL);
     if (NULL == f) {
-        fprintf(stderr,"no font available\n");
-        exit(1);
+	fprintf(stderr,"no font available\n");
+	exit(1);
     }
 }
 
@@ -421,7 +414,7 @@ static void do_capture(int from, int to, int tmp_switch)
 	}
 	dx += (fb_var.xres-24-fmt.width)/2;
 	dy += (fb_var.yres-16-fmt.height)/2;
-	
+
 	if (f_drv & CAN_CAPTURE)
 	    drv->startvideo(h_drv,-1,2);
 	break;
@@ -524,6 +517,7 @@ do_fullscreen(void)
 static void
 grabber_init(void)
 {
+    drv = NULL;
     struct ng_video_fmt screen;
 
     memset(&screen,0,sizeof(screen));
@@ -531,7 +525,8 @@ grabber_init(void)
     screen.width        = fb_var.xres_virtual;
     screen.height       = fb_var.yres_virtual;
     screen.bytesperline = fb_fix.line_length;
-    drv = ng_vid_open(ng_dev.video,NULL,&screen,0,&h_drv);
+
+    drv = ng_vid_open(&ng_dev.video, ng_dev.driver, &screen, 0, &h_drv);
     if (NULL == drv) {
 	fprintf(stderr,"no grabber device available\n");
 	exit(1);
@@ -552,7 +547,7 @@ console_switch(void)
 	break;
     case FB_ACQ_REQ:
 	switch_last = fb_switch_state;
-        fb_switch_acquire();
+	fb_switch_acquire();
 	fb_memset(fb_mem+fb_mem_offset,0,fb_fix.smem_len);
 	ioctl(fb,FBIOPAN_DISPLAY,&fb_var);
 	do_va_cmd(2,"capture","on");
@@ -607,7 +602,7 @@ main(int argc, char *argv[])
     ng_init();
     for (;;) {
 	double val;
-	c = getopt(argc, argv, "Mgvqxkd:o:s:c:f:m:z:t:j:");
+	c = getopt(argc, argv, "Mgvqxk2d:o:s:c:f:m:z:t:j:D:");
 	if (c == -1)
 	    break;
 	switch (c) {
@@ -653,9 +648,9 @@ main(int argc, char *argv[])
 	    break;
 	case 'c':
 	    ng_dev.video = optarg;
-	    /* v4l-conf needs this too */
-	    strcat(ng_v4l_conf," -c ");
-	    strcat(ng_v4l_conf,ng_dev.video);
+	    break;
+	case 'D':
+	    ng_dev.driver = optarg;
 	    break;
 	case 't':
 	    if (optarg)
@@ -685,7 +680,7 @@ main(int argc, char *argv[])
 	    matrox = 0;
     if (matrox)
 	strcat(ng_v4l_conf," -y ");
-    
+
     grabber_init();
     freq_init();
     read_config(NULL,NULL,NULL);
