@@ -25,7 +25,6 @@ extern char ng_v4l_conf[256];
 
 #if __STDC_VERSION__ < 199901
 # define restrict
-# define bool int
 #endif
 
 #define UNSET          (-1U)
@@ -286,19 +285,19 @@ struct ng_vid_driver {
     const char *name;
 
     /* open/close */
-    void*  (*open)(char *device);
+    void*  (*open)(char *device, int req_flags);
     int    (*close)(void *handle);
 
     /* attributes */
     char* (*get_devname)(void *handle);
     int   (*capabilities)(void *handle);
     struct ng_attribute* (*list_attrs)(void *handle);
-    
+
     /* overlay */
     int   (*setupfb)(void *handle, struct ng_video_fmt *fmt, void *base);
     int   (*overlay)(void *handle, struct ng_video_fmt *fmt, int x, int y,
 		     struct OVERLAY_CLIP *oc, int count, int aspect);
-    
+
     /* capture */
     int   (*setformat)(void *handle, struct ng_video_fmt *fmt);
     int   (*startvideo)(void *handle, int fps, unsigned int buffers);
@@ -446,7 +445,7 @@ struct ng_video_conv* ng_conv_find_to(unsigned int out, int *i);
 struct ng_video_conv* ng_conv_find_from(unsigned int out, int *i);
 struct ng_video_conv* ng_conv_find_match(unsigned int in, unsigned int out);
 
-const struct ng_vid_driver* ng_vid_open(char *device, char *driver,
+const struct ng_vid_driver* ng_vid_open(char **device, char *driver,
 					struct ng_video_fmt *screen,
 					void *base, void **handle);
 const struct ng_dsp_driver* ng_dsp_open(char *device, struct ng_audio_fmt *fmt,
