@@ -165,15 +165,16 @@ void watch_audio(XtPointer data, XtIntervalId *id);
 static struct MY_TOPLEVELS {
     char        *name;
     Widget      *shell;
+    int         require_tune;
     int         *check;
     int          first;
     int          mapped;
 } my_toplevels [] = {
-    { "options",  &opt_shell              },
-    { "channels", &chan_shell,   &count   },
-    { "config",   &conf_shell,            },
-    { "streamer", &str_shell              },
-    { "launcher", &launch_shell, &nlaunch }
+    { "options",  &opt_shell,    0,          },
+    { "channels", &chan_shell,   1, &count   },
+    { "config",   &conf_shell,   1,          },
+    { "streamer", &str_shell,    0,          },
+    { "launcher", &launch_shell, 0, &nlaunch }
 };
 #define TOPLEVELS (sizeof(my_toplevels)/sizeof(struct MY_TOPLEVELS))
 
@@ -234,7 +235,9 @@ PopupAction(Widget widget, XEvent *event,
     Dimension h;
     unsigned int i;
     int mh;
-
+    if (debug)
+	fprintf(stderr,"PopupAction: %s\n",
+	        (*num_params > 0) ? params[0] : "-");
     /* which window we are talking about ? */
     if (*num_params > 0) {
 	for (i = 0; i < TOPLEVELS; i++) {
@@ -253,6 +256,10 @@ PopupAction(Widget widget, XEvent *event,
 	return;
     }
 
+    if (!(f_drv & CAN_TUNE) && my_toplevels[i].require_tune)
+	return;
+
+
     /* Message from WM ??? */
     if (NULL != event && event->type == ClientMessage) {
 	if (debug)
@@ -309,7 +316,7 @@ action_cb(Widget widget, XtPointer clientdata, XtPointer call_data)
 
 void toolkit_set_label(Widget widget, char *str)
 {
-    XtVaSetValues(widget,XtNlabel,str,NULL);    
+    XtVaSetValues(widget,XtNlabel,str,NULL);
 }
 
 /*--- videotext ----------------------------------------------------------*/
@@ -468,7 +475,7 @@ resize_event(Widget widget, XtPointer client_data, XEvent *event, Boolean *d)
 {
     static int width = 0, height = 0, first = 1;
     char label[64];
-    
+
     switch(event->type) {
     case ConfigureNotify:
 	if (first) {
@@ -499,12 +506,12 @@ set_float(Widget widget, char *name, float value)
 
     if (sizeof(float) > sizeof(XtArgVal)) {
 	/*
-	 * If a float is larger than an XtArgVal then pass this 
+	 * If a float is larger than an XtArgVal then pass this
 	 * resource value by reference.
 	 */
 	XtSetArg(args[0], name, &value);
     } else {
-        /*
+	/*
 	 * Convince C not to perform an automatic conversion, which
 	 * would truncate 0.5 to 0.
 	 *
@@ -585,7 +592,7 @@ new_channel(void)
 		 (cur_channel == -1) ? NULL : chanlist[cur_channel].name,
 		 (cur_sender == -1)  ? NULL : channels[cur_sender]->name);
     conf_station_switched();
-    
+
     if (zap_timer) {
 	XtRemoveTimeOut(zap_timer);
 	zap_timer = 0;
@@ -706,7 +713,7 @@ pixit(void)
     if (channels[cur_sender]->pixmap)
 	XFreePixmap(dpy,channels[cur_sender]->pixmap);
     channels[cur_sender]->pixmap = pix;
-    
+
  done2:
     ng_release_video_buf(buf);
  done1:
@@ -734,6 +741,9 @@ ChannelAction(Widget widget, XEvent *event,
 {
     int i;
 
+    if (!(f_drv & CAN_TUNE))
+	return;
+
     if (0 == count)
 	return;
     i = popup_menu(widget,"Stations",cmenu);
@@ -744,6 +754,9 @@ ChannelAction(Widget widget, XEvent *event,
 
 static void create_chanwin(void)
 {
+    if (!(f_drv & CAN_TUNE))
+	return;
+
     chan_shell = XtVaAppCreateShell("Channels", "Xawtv",
 				    topLevelShellWidgetClass,
 				    dpy,
@@ -773,6 +786,9 @@ void channel_menu(void)
     int  i,max,len;
     char str[100];
 
+    if (!(f_drv & CAN_TUNE))
+	return;
+
     if (cmenu)
 	free(cmenu);
     cmenu = malloc((count+1)*sizeof(struct STRTAB));
@@ -809,7 +825,7 @@ StayOnTop(Widget widget, XEvent *event,
     stay_on_top = stay_on_top ? 0 : 1;
     if (debug)
 	fprintf(stderr,"stay_on_top: %d\n",stay_on_top);
-	
+
     wm_stay_on_top(dpy,XtWindow(app_shell),stay_on_top);
     wm_stay_on_top(dpy,XtWindow(on_shell),stay_on_top);
     for (i = 0; i < TOPLEVELS; i++)
@@ -861,7 +877,7 @@ update_movie_menus(void)
     for (i = 0; NULL != movie_driver->audio[i].name; i++) {
 	m_movie_audio[i].nr  = i;
 	m_movie_audio[i].str = movie_driver->audio[i].desc ?
-	    movie_driver->audio[i].desc : 
+	    movie_driver->audio[i].desc :
 	    ng_afmt_to_desc[movie_driver->audio[i].fmtid];
 	if (NULL != mov_audio)
 	    if (0 == strcasecmp(mov_audio,movie_driver->audio[i].name))
@@ -881,7 +897,7 @@ update_movie_menus(void)
     for (i = 0; NULL != movie_driver->video[i].name; i++) {
 	m_movie_video[i].nr  = i;
 	m_movie_video[i].str = movie_driver->video[i].desc ?
-	    movie_driver->video[i].desc : 
+	    movie_driver->video[i].desc :
 	    ng_vfmt_to_desc[movie_driver->video[i].fmtid];
 	if (NULL != mov_video)
 	    if (0 == strcasecmp(mov_video,movie_driver->video[i].name))
@@ -915,9 +931,9 @@ init_movie_menus(void)
 }
 
 #define PANED_FIX               \
-        XtNallowResize, False,  \
-        XtNshowGrip,    False,  \
-        XtNskipAdjust,  True
+	XtNallowResize, False,  \
+	XtNshowGrip,    False,  \
+	XtNskipAdjust,  True
 
 struct DO_CMD cmd_fs   = { 1, { "fullscreen",        NULL }};
 struct DO_CMD cmd_mute = { 2, { "volume",  "mute",   NULL }};
@@ -980,7 +996,7 @@ menu_cb(Widget widget, XtPointer clientdata, XtPointer call_data)
 	    int i = 0;
 	    struct list_head *item;
 	    struct ng_writer *writer = NULL;
-	    
+
 	    list_for_each(item,&ng_writers) {
 		if (i++ == j)
 		    writer = list_entry(item,struct ng_writer, list);
@@ -1091,7 +1107,7 @@ add_attr_option(Widget paned, struct ng_attribute *attr)
     a = malloc(sizeof(*a));
     memset(a,0,sizeof(*a));
     a->attr = attr;
-    
+
     switch (attr->type) {
     case ATTR_TYPE_BOOL:
     case ATTR_TYPE_CHOICE:
@@ -1140,11 +1156,11 @@ create_optwin(void)
 			   ("<Message>WM_PROTOCOLS: Popup()"));
     opt_paned = XtVaCreateManagedWidget("paned", panedWidgetClass, opt_shell,
 					NULL);
-    
+
     c = XtVaCreateManagedWidget("mute", commandWidgetClass, opt_paned,
 				PANED_FIX, NULL);
     XtAddCallback(c,XtNcallback,command_cb,(XtPointer)&cmd_mute);
-    
+
     c = XtVaCreateManagedWidget("fs", commandWidgetClass, opt_paned,
 				PANED_FIX, NULL);
     XtAddCallback(c,XtNcallback,command_cb,(XtPointer)&cmd_fs);
@@ -1158,18 +1174,20 @@ create_optwin(void)
     c = XtVaCreateManagedWidget("recavi", commandWidgetClass, opt_paned,
 				PANED_FIX, NULL);
     XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_avi);
-    c = XtVaCreateManagedWidget("chanwin", commandWidgetClass, opt_paned,
-				PANED_FIX, NULL);
-    XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_chan);
-    c = XtVaCreateManagedWidget("confwin", commandWidgetClass, opt_paned,
-				PANED_FIX, NULL);
-    XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_conf);
+    if (f_drv & CAN_TUNE) {
+	c = XtVaCreateManagedWidget("chanwin", commandWidgetClass, opt_paned,
+				    PANED_FIX, NULL);
+	XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_chan);
+	c = XtVaCreateManagedWidget("confwin", commandWidgetClass, opt_paned,
+				    PANED_FIX, NULL);
+	XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_conf);
+	c = XtVaCreateManagedWidget("zap", commandWidgetClass, opt_paned,
+				    PANED_FIX, NULL);
+	XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_zap);
+    }
     c = XtVaCreateManagedWidget("launchwin", commandWidgetClass, opt_paned,
 				PANED_FIX, NULL);
     XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_launch);
-    c = XtVaCreateManagedWidget("zap", commandWidgetClass, opt_paned,
-				PANED_FIX, NULL);
-    XtAddCallback(c,XtNcallback,action_cb,(XtPointer)&ac_zap);
     if (wm_stay_on_top) {
 	c = XtVaCreateManagedWidget("top", commandWidgetClass, opt_paned,
 				    PANED_FIX, NULL);
@@ -1210,7 +1228,7 @@ create_attr_widgets(void)
 	    continue;
 	add_attr_option(opt_paned,attr);
     }
-    
+
     /* integer options */
     attr = ng_attr_byid(attrs,ATTR_ID_BRIGHT);
     if (NULL != attr)
@@ -1408,7 +1426,7 @@ do_movie_record(int argc, char **argv)
 	XtVaSetValues(w_movie_status,XtNlabel,"recording",NULL);
 	return;
     }
-    
+
     /* stop */
     if (argc > 0 && 0 == strcasecmp(argv[0],"stop")) {
 	if (0 == cur_movie)
@@ -1452,7 +1470,7 @@ create_strwin(void)
 			   ("<Message>WM_PROTOCOLS: Popup()"));
 
     form = XtVaCreateManagedWidget("form", formWidgetClass, str_shell,
-                                   NULL);
+				   NULL);
 
     /* driver */
     button = XtVaCreateManagedWidget("driver", commandWidgetClass, form,
@@ -1470,7 +1488,7 @@ create_strwin(void)
 				   XtNfromVert, label,
 				   NULL);
     w_movie_fvideo = text;
-    
+
     /* audio filename */
     label = XtVaCreateManagedWidget("alabel", labelWidgetClass, form,
 				    FIX_LEFT_TOP,
@@ -1526,7 +1544,7 @@ create_strwin(void)
 				     XtNfromVert, label,
 				     NULL);
     XtAddCallback(button,XtNcallback,exec_record,NULL);
-    
+
     button = XtVaCreateManagedWidget("xanim", commandWidgetClass, form,
 				     FIX_LEFT_TOP,
 				     XtNfromVert, button,
@@ -1606,7 +1624,7 @@ main(int argc, char *argv[])
 #endif
 	grabber_scan();
     }
-    
+
     /* look for a useful visual */
     visual_init("xawtv","Xawtv");
 
@@ -1636,7 +1654,7 @@ main(int argc, char *argv[])
     if (args.xv_image)
 	xv_image_init(dpy);
 #endif
-    
+
     /* set hooks (command.c) */
     update_title        = new_title;
     display_message     = new_message;
@@ -1648,9 +1666,14 @@ main(int argc, char *argv[])
 #endif
     attr_notify         = new_attr;
     volume_notify       = new_volume;
-    freqtab_notify      = new_freqtab;
-    setfreqtab_notify   = new_freqtab;
-    setstation_notify   = new_channel;
+    if (f_drv & CAN_TUNE) {
+	freqtab_notify      = new_freqtab;
+	setfreqtab_notify   = new_freqtab;
+	setstation_notify   = new_channel;
+	channel_switch_hook = pixit;
+    } else {
+	new_title("Capture");
+    }
     set_capture_hook    = do_capture;
     fullscreen_hook     = do_fullscreen;
     movie_hook          = do_movie_record;
@@ -1658,8 +1681,7 @@ main(int argc, char *argv[])
     exit_hook           = do_exit;
     capture_get_hook    = video_gd_suspend;
     capture_rel_hook    = video_gd_restart;
-    channel_switch_hook = pixit;
-    
+
     if (debug)
 	fprintf(stderr,"main: init main window...\n");
     tv = video_init(app_shell, &vinfo, simpleWidgetClass,
@@ -1686,7 +1708,8 @@ main(int argc, char *argv[])
     create_onscreen(labelWidgetClass);
     create_vtx();
     create_chanwin();
-    create_confwin();
+    if ((f_drv & CAN_TUNE))
+	create_confwin();
     create_strwin();
     create_launchwin();
 
@@ -1708,9 +1731,9 @@ main(int argc, char *argv[])
     }
     init_movie_menus();
     create_attr_widgets();
-    
+
     xt_vm_randr_input_init(dpy);
-    
+
     if (debug)
 	fprintf(stderr,"main: mapping main window ...\n");
     XtRealizeWidget(app_shell);
@@ -1726,9 +1749,10 @@ main(int argc, char *argv[])
 		  XtNminWidth,  WIDTH_INC,
 		  XtNminHeight, HEIGHT_INC,
 		  NULL);
-    XtVaSetValues(chan_shell,
-		  XtNwidth,pix_width*pix_cols+30,
-		  NULL);
+    if (f_drv & CAN_TUNE)
+	XtVaSetValues(chan_shell,
+		      XtNwidth,pix_width*pix_cols+30,
+		      NULL);
 
     /* mouse pointer magic */
     XtAddEventHandler(tv, PointerMotionMask, True, mouse_event, NULL);
@@ -1742,21 +1766,22 @@ main(int argc, char *argv[])
     audio_init();
 
     /* build channel list */
-    if (args.readconfig) {
+    if (args.readconfig &&(f_drv & CAN_TUNE)) {
 	if (debug)
 	    fprintf(stderr,"main: parse channels from config file ...\n");
 	parse_config();
     }
+
     channel_menu();
 
     xt_handle_pending(dpy);
     init_overlay();
 
     set_property(0,NULL,NULL);
-    if (optind+1 == argc) {
+    if (optind+1 == argc && (f_drv & CAN_TUNE)) {
 	do_va_cmd(2,"setstation",argv[optind]);
-    } else {
-	if ((f_drv & CAN_TUNE) && 0 != (freq = drv->getfreq(h_drv))) {
+    } else if (f_drv & CAN_TUNE) {
+	if (0 != (freq = drv->getfreq(h_drv))) {
 	    for (i = 0; i < chancount; i++)
 		if (chanlist[i].freq == freq*1000/16) {
 		    do_va_cmd(2,"setchannel",chanlist[i].name);
