@@ -22,10 +22,10 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <pthread.h>
-
 #if defined(__linux__)
 # include <sys/ioctl.h>
-# include "videodev.h"
+#include <linux/types.h>
+# include "videodev2.h"
 #endif
 
 #include "config.h"
@@ -57,6 +57,8 @@
 #include "blit.h"
 #include "parseconfig.h"
 #include "event.h"
+#include "alsa_stream.h"
+#include "get_media_devices.h"
 
 /* jwz */
 #include "remote.h"
@@ -146,6 +148,22 @@ XtResource args_desc[] = {
 	XtCString, XtRString, sizeof(char*),
 	XtOffset(struct ARGS*,conffile),
 	XtRString, NULL
+    },{
+	"alsa_cap",
+	XtCString, XtRString, sizeof(char*),
+	XtOffset(struct ARGS*,alsa_cap),
+	XtRString, NULL
+    },{
+	"alsa_pb",
+	XtCString, XtRString, sizeof(char*),
+	XtOffset(struct ARGS*,alsa_pb),
+	XtRString, NULL
+    },{
+	/* Integer */
+	"alsa_latency",
+	XtCValue, XtRInt, sizeof(int),
+	XtOffset(struct ARGS*,alsa_latency),
+	XtRString, "30"
     },{
 	/* Integer */
 	"debug",
@@ -218,6 +236,11 @@ XtResource args_desc[] = {
 	XtCBoolean, XtRBoolean, sizeof(int),
 	XtOffset(struct ARGS*,gl),
 	XtRString, "1"
+    },{
+	"alsa",
+	XtCBoolean, XtRBoolean, sizeof(int),
+	XtOffset(struct ARGS*,alsa),
+	XtRString, "1"
     },{
 	"vidmode",
 	XtCBoolean, XtRBoolean, sizeof(int),
@@ -251,6 +274,7 @@ const int args_count = XtNumber(args_desc);
 XrmOptionDescRec opt_desc[] = {
     { "-c",          "device",      XrmoptionSepArg, NULL },
     { "-device",     "device",      XrmoptionSepArg, NULL },
+    { "-D",          "driver",      XrmoptionSepArg, NULL },
     { "-driver",     "driver",      XrmoptionSepArg, NULL },
     { "-C",          "dspdev",      XrmoptionSepArg, NULL },
     { "-dspdev",     "dspdev",      XrmoptionSepArg, NULL },
@@ -259,7 +283,7 @@ XrmOptionDescRec opt_desc[] = {
     { "-o",          "basename",    XrmoptionSepArg, NULL },
     { "-outfile",    "basename",    XrmoptionSepArg, NULL },
     { "-conffile",   "conffile",    XrmoptionSepArg, NULL },
-    
+
     { "-v",          "debug",       XrmoptionSepArg, NULL },
     { "-debug",      "debug",       XrmoptionSepArg, NULL },
     { "-b",          "bpp",         XrmoptionSepArg, NULL },
@@ -268,7 +292,11 @@ XrmOptionDescRec opt_desc[] = {
     { "-xvport",     "xvport",      XrmoptionSepArg, NULL },
     { "-parallel",   "parallel",    XrmoptionSepArg, NULL },
     { "-bufcount",   "bufcount",    XrmoptionSepArg, NULL },
-    
+
+    { "-alsa-cap",   "alsa_cap",    XrmoptionSepArg, NULL },
+    { "-alsa-pb",    "alsa_pb",     XrmoptionSepArg, NULL },
+    { "-alsa-latency", "alsa_latency", XrmoptionSepArg, NULL },
+
     { "-remote",     "remote",      XrmoptionNoArg,  "1" },
     { "-n",          "readconfig",  XrmoptionNoArg,  "0" },
     { "-noconf",     "readconfig",  XrmoptionNoArg,  "0" },
@@ -276,7 +304,7 @@ XrmOptionDescRec opt_desc[] = {
     { "-fullscreen", "fullscreen",  XrmoptionNoArg,  "1" },
     { "-hwscan",     "hwscan",      XrmoptionNoArg,  "1" },
     { "-fb",         "fbdev",       XrmoptionNoArg,  "1" },
-    
+
     { "-xv",         "xv",          XrmoptionNoArg,  "1" },
     { "-noxv",       "xv",          XrmoptionNoArg,  "0" },
     { "-xv-video",   "xvVideo",     XrmoptionNoArg,  "1" },
@@ -286,13 +314,16 @@ XrmOptionDescRec opt_desc[] = {
     { "-gl",         "gl",          XrmoptionNoArg,  "1" },
     { "-nogl",       "gl",          XrmoptionNoArg,  "0" },
 
+    { "-alsa",       "alsa",        XrmoptionNoArg,  "1" },
+    { "-noalsa",     "alsa",        XrmoptionNoArg,  "0" },
+
     { "-vm",         "vidmode",     XrmoptionNoArg,  "1" },
     { "-novm",       "vidmode",     XrmoptionNoArg,  "0" },
     { "-dga",        "dga",         XrmoptionNoArg,  "1" },
     { "-nodga",      "dga",         XrmoptionNoArg,  "0" },
     { "-randr",      "randr",       XrmoptionNoArg,  "1" },
     { "-norandr",    "randr",       XrmoptionNoArg,  "0" },
-    
+
     { "-h",          "help",        XrmoptionNoArg,  "1" },
     { "-help",       "help",        XrmoptionNoArg,  "1" },
     { "--help",      "help",        XrmoptionNoArg,  "1" },
@@ -313,6 +344,12 @@ ExitWP(XtPointer client_data)
 void
 ExitCB(Widget widget, XtPointer client_data, XtPointer calldata)
 {
+    static int exit_pending = 0;
+
+    if (exit_pending)
+	return;
+
+    exit_pending = 1;
     audio_off();
     video_overlay(0);
     video_close();
@@ -378,9 +415,9 @@ RemoteAction(Widget widget, XEvent * event,
 		    argv[argc] = NULL;
 		    do_command(argc,argv);
 		    argc = 0;
-	        } else {
+		} else {
 		    argv[argc++] = args+i;
-	        }
+		}
 	    }
 	    XFree(args);
 	}
@@ -415,6 +452,8 @@ void
 ZapAction(Widget widget, XEvent *event,
 	  String *params, Cardinal *num_params)
 {
+    if (!(f_drv & CAN_TUNE))
+	return;
     if (zap_timer) {
 	XtRemoveTimeOut(zap_timer);
 	zap_timer = 0;
@@ -439,7 +478,7 @@ static void
 scan_timeout(XtPointer client_data, XtIntervalId *id)
 {
     scan_timer = 0;
-    
+
     /* check */
     if (!(f_drv & CAN_TUNE))
 	return;
@@ -455,6 +494,8 @@ void
 ScanAction(Widget widget, XEvent *event,
 	   String *params, Cardinal *num_params)
 {
+    if (!(f_drv & CAN_TUNE))
+	return;
     if (channel_switch_hook)
 	channel_switch_hook();
     do_va_cmd(2,"setchannel","next");
@@ -467,7 +508,7 @@ RatioAction(Widget widget, XEvent *event,
 	    String *params, Cardinal *num_params)
 {
     int w,h;
-    
+
     if (2 != *num_params)
 	return;
     w = atoi(params[0]);
@@ -640,7 +681,7 @@ exec_player(char *moviefile)
     char *cmd;
     char **argv;
     int  argc;
-    
+
     /* go! */
     cmd = malloc(strlen(command)+strlen(moviefile)+5);
     sprintf(cmd,"%s %s",command,moviefile);
@@ -654,7 +695,7 @@ LaunchAction(Widget widget, XEvent *event,
 {
     char **argv;
     int  i,argc;
-    
+
     if (*num_params != 1)
 	return;
     for (i = 0; i < nlaunch; i++) {
@@ -728,7 +769,7 @@ xt_siginit(void)
 
     act.sa_handler  = SIG_IGN;
     sigaction(SIGPIPE,&act,&old);
-    
+
     if (debug) {
 	act.sa_handler  = segfault;
 	sigaction(SIGSEGV,&act,&old);
@@ -804,7 +845,7 @@ do_vidmode_modeswitch(int fs_state, int *vp_width, int *vp_height)
     static XF86VidModeModeInfo  *vm_current    = NULL;
     static XF86VidModeModeInfo  *vm_fullscreen = NULL;
     int i;
-    
+
     if (fs_state) {
 	/* enter fullscreen mode */
 	XF86VidModeGetModeLine(dpy,XDefaultScreen(dpy),&vm_dot,&vm_line);
@@ -860,7 +901,7 @@ do_randr_modeswitch(int fs_state, int *vp_width, int *vp_height)
     XRRScreenConfiguration *sc;
     Rotation rotation;
     SizeID current, new, i;
-    
+
     sc = XRRGetScreenInfo(dpy, root);
     current = XRRConfigCurrentConfiguration(sc, &rotation);
     new = current;
@@ -937,10 +978,10 @@ do_screensaver(int fs_state)
 			&prefer_blanking,&allow_exposures);
 	XSetScreenSaver(dpy,0,0,DefaultBlanking,DefaultExposures);
 #ifdef HAVE_LIBXDPMS
-	if ((DPMSQueryExtension(dpy, &dpms_dummy, &dpms_dummy)) && 
+	if ((DPMSQueryExtension(dpy, &dpms_dummy, &dpms_dummy)) &&
 	    (DPMSCapable(dpy))) {
 	    DPMSInfo(dpy, &dpms_state, &dpms_on);
-            DPMSDisable(dpy); 
+	    DPMSDisable(dpy);
 	}
 #endif
 	xscreensaver_timer = XtAppAddTimeOut(app_context,60000,
@@ -949,7 +990,7 @@ do_screensaver(int fs_state)
 	/* fullscreen off -- enable screensaver */
 	XSetScreenSaver(dpy,timeout,interval,prefer_blanking,allow_exposures);
 #ifdef HAVE_LIBXDPMS
-	if ((DPMSQueryExtension(dpy, &dpms_dummy, &dpms_dummy)) && 
+	if ((DPMSQueryExtension(dpy, &dpms_dummy, &dpms_dummy)) &&
 	    (DPMSCapable(dpy)) && (dpms_on)) {
 		DPMSEnable(dpy);
 	}
@@ -993,13 +1034,13 @@ do_fullscreen(void)
 	if (debug)
 	    fprintf(stderr,"turning fs off (%dx%d+%d+%d)\n",w,h,x,y);
 	do_modeswitch(0,&vp_width,&vp_height);
-	
+
 	if (on_timer) {
 	    XtPopdown(on_shell);
 	    XtRemoveTimeOut(on_timer);
 	    on_timer = 0;
 	}
-	
+
 	XtVaSetValues(app_shell,
 		      XtNwidthInc, WIDTH_INC,
 		      XtNheightInc,HEIGHT_INC,
@@ -1010,7 +1051,7 @@ do_fullscreen(void)
 		      NULL);
 
 	do_screensaver(0);
-    	if (warp_pointer)
+	if (warp_pointer)
 	    XWarpPointer(dpy, None, RootWindowOfScreen(XtScreen(tv)),
 			 0, 0, 0, 0, rpx, rpy);
 	fs = 0;
@@ -1047,7 +1088,7 @@ do_fullscreen(void)
 	    int i;
 	    for (i = 0; i < nxinerama; i++) {
 		if (x >= xinerama[i].x_org &&
-		    y >= xinerama[i].y_org && 
+		    y >= xinerama[i].y_org &&
 		    x <  xinerama[i].x_org + xinerama[i].width &&
 		    y <  xinerama[i].y_org + xinerama[i].height) {
 		    vp_x      = xinerama[i].x_org;
@@ -1074,7 +1115,7 @@ do_fullscreen(void)
 		      XtNheight,     vp_height,
 		      NULL);
 
-        XRaiseWindow(dpy, XtWindow(app_shell));
+	XRaiseWindow(dpy, XtWindow(app_shell));
 	do_screensaver(1);
 	if (warp_pointer)
 	    XWarpPointer(dpy, None, XtWindow(tv), 0, 0, 0, 0, 30, 15);
@@ -1171,9 +1212,9 @@ set_property(int freq, char *channel, char *name)
     len += sprintf(line+len,"%s",channel ? channel : "?") +1;
     len += sprintf(line+len,"%s",name    ? name    : "?") +1;
     XChangeProperty(dpy, XtWindow(app_shell),
-                    _XAWTV_STATION, XA_STRING,
-                    8, PropModeReplace,
-                    line, len);
+		    _XAWTV_STATION, XA_STRING,
+		    8, PropModeReplace,
+		    line, len);
 }
 
 void command_cb(Widget widget, XtPointer clientdata, XtPointer call_data)
@@ -1247,18 +1288,21 @@ FilterAction(Widget widget, XEvent *event,
 }
 
 /*----------------------------------------------------------------------*/
+#ifdef HAVE_LIBXXF86DGA
+static int xfree_dga_error_base;
+#endif
 
 void
 xfree_dga_init(Display *dpy)
 {
 #ifdef HAVE_LIBXXF86DGA
-    int  flags,foo,bar,ma,mi;
+    int  flags,foo,ma,mi;
 
     if (!do_overlay)
 	return;
-    
+
     if (args.dga) {
-	if (XF86DGAQueryExtension(dpy,&foo,&bar)) {
+	if (XF86DGAQueryExtension(dpy,&foo,&xfree_dga_error_base)) {
 	    XF86DGAQueryDirectVideo(dpy,XDefaultScreen(dpy),&flags);
 	    if (flags & XF86DGADirectPresent) {
 		XF86DGAQueryVersion(dpy,&ma,&mi);
@@ -1294,7 +1338,7 @@ xfree_vm_init(Display *dpy)
 		    fprintf(stderr," %dx%d",
 			    vm_modelines[i]->hdisplay,
 			    vm_modelines[i]->vdisplay);
-		}	    
+		}
 		fprintf(stderr,"\n");
 	    }
 	}
@@ -1307,7 +1351,7 @@ xfree_randr_init(Display *dpy)
 {
 #ifdef HAVE_LIBXRANDR
     int bar,i;
-    
+
     if (args.randr) {
 	if (XRRQueryExtension(dpy,&randr_evbase,&bar)) {
 	    randr = XRRSizes(dpy,DefaultScreen(dpy),&nrandr);
@@ -1332,7 +1376,7 @@ xfree_xinerama_init(Display *dpy)
 {
 #ifdef HAVE_LIBXINERAMA
     int foo,bar,i;
-    
+
     if (XineramaQueryExtension(dpy,&foo,&bar) &&
 	XineramaIsActive(dpy)) {
 	xinerama = XineramaQueryScreens(dpy,&nxinerama);
@@ -1348,24 +1392,48 @@ xfree_xinerama_init(Display *dpy)
 #endif
 }
 
+#ifdef HAVE_LIBXXF86DGA
+static int (*orig_xfree_error_handler)(Display *, XErrorEvent *);
+
+static int xfree_dga_error_handler(Display *d, XErrorEvent *e)
+{
+  if (e->error_code == (xfree_dga_error_base + XF86DGANoDirectVideoMode)) {
+    have_dga = 0;
+    return 0;
+  }
+  return orig_xfree_error_handler(d, e);
+}
+#endif
+
 void
 grabber_init()
 {
     struct ng_video_fmt screen;
     void *base = NULL;
+#if defined(HAVE_ALSA)
+    void *md;
+    char *alsa_cap, *alsa_out, *p;
+#endif
 
     memset(&screen,0,sizeof(screen));
 #ifdef HAVE_LIBXXF86DGA
     if (have_dga) {
 	int bar,fred;
-    	XF86DGAGetVideoLL(dpy,XDefaultScreen(dpy),(void*)&base,
-			  &screen.bytesperline,&bar,&fred);
+	orig_xfree_error_handler = XSetErrorHandler(xfree_dga_error_handler);
+	if (!XF86DGAGetVideoLL(dpy,XDefaultScreen(dpy),(void*)&base,
+			      &screen.bytesperline,&bar,&fred)) {
+	    have_dga = 0;
+	    memset(&screen,0,sizeof(screen));	/*  paranoia   */
+	    base = NULL;			/*  paranoia   */
+	}
+	XSync(dpy, 0);
+	XSetErrorHandler(orig_xfree_error_handler);
     }
 #endif
     if (!do_overlay) {
 	if (debug)
 	    fprintf(stderr,"x11: remote display (overlay disabled)\n");
-	drv = ng_vid_open(args.device, args.driver, NULL, base, &h_drv);
+	drv = ng_vid_open(&args.device, args.driver, NULL, base, &h_drv);
     } else {
 	screen.width  = XtScreen(app_shell)->width;
 	screen.height = XtScreen(app_shell)->height;
@@ -1378,7 +1446,7 @@ grabber_init()
 		    screen.bytesperline,
 		    have_dga ? ", DGA"     : "",
 		    have_vm  ? ", VidMode" : "");
-	drv = ng_vid_open(args.device, args.driver, &screen, base, &h_drv);
+	drv = ng_vid_open(&args.device, args.driver, &screen, base, &h_drv);
     }
     if (NULL == drv) {
 	fprintf(stderr,"no video grabber device available\n");
@@ -1386,6 +1454,32 @@ grabber_init()
     }
     f_drv = drv->capabilities(h_drv);
     add_attrs(drv->list_attrs(h_drv));
+
+#if defined(HAVE_ALSA)
+    if (args.alsa) {
+	/* Start audio capture thread */
+	md = discover_media_devices();
+	p = strrchr(args.device, '/');
+	if (p)
+	    p++;
+	else
+	    p = args.device;
+	alsa_cap = (char *)get_associated_device(md, NULL, MEDIA_SND_CAP,
+						 p, MEDIA_V4L_VIDEO);
+	alsa_out = "default";
+	if (args.alsa_cap)
+		alsa_cap = args.alsa_cap;
+
+	if (args.alsa_pb)
+		alsa_out = args.alsa_pb;
+	fprintf(stderr, "Alsa devices: cap: %s (%s), out: %s\n",
+		alsa_cap, args.device, alsa_out);
+
+	if (alsa_cap && alsa_out)
+	    alsa_thread_startup(alsa_out, alsa_cap, args.alsa_latency, stderr, debug);
+	free_media_devices(md);
+    }
+#endif
 }
 
 void
@@ -1412,7 +1506,7 @@ grabber_scan(void)
 	}
 	close(fh);
 
-	driver = ng_vid_open(ng_dev.video_scan[i], args.driver,
+	driver = ng_vid_open(&ng_dev.video_scan[i], args.driver,
 			     NULL, NULL, &handle);
 	if (NULL == driver) {
 	    fprintf(stderr,"%s: initialization failed\n",ng_dev.video_scan[i]);
@@ -1448,7 +1542,7 @@ x11_check_remote()
 
     if (debug)
 	fprintf(stderr, "check if the X-Server is local ... ");
-    
+
     /* me */
     length = sizeof(ss);
     if (-1 == getsockname(fd,(struct sockaddr*)&ss,&length)) {
@@ -1464,7 +1558,7 @@ x11_check_remote()
 	    fprintf(stderr, " ok (unix socket)\n");
 	return;
     }
-    
+
     getnameinfo((struct sockaddr*)&ss,length,
 		me,INET6_ADDRSTRLEN,port,16,
 		NI_NUMERICHOST | NI_NUMERICSERV);
@@ -1547,8 +1641,6 @@ v4lconf_init()
 	sprintf(ng_v4l_conf+strlen(ng_v4l_conf)," -s %d",args.shift);
     if (args.bpp)
 	sprintf(ng_v4l_conf+strlen(ng_v4l_conf)," -b %d",args.bpp);
-    if (args.device)
-	sprintf(ng_v4l_conf+strlen(ng_v4l_conf)," -c %s",args.device);
 }
 
 static void
@@ -1582,10 +1674,17 @@ usage(void)
 #endif
 #ifdef HAVE_GL
 	    "      -(no)gl         enable/disable OpenGL\n"
+#endif
+#ifdef HAVE_ALSA
+	    "      -(no)alsa       enable/disable alsa streaming. Default: enabled\n"
+	    "      -(no)alsa-cap   manually specify an alsa capture interface\n"
+	    "      -(no)alsa-pb    manually specify an alsa playback interface\n"
+	    "      -alsa-latency   manually specify an alsa latency in ms. Default: 30\n"
 #endif
 	    "  -b  -bpp n          color depth of the display is n (n=24,32)\n"
 	    "  -o  -outfile file   filename base for snapshots\n"
 	    "  -c  -device file    use <file> as video4linux device\n"
+	    "  -D  -driver name    use <name> as video4linux driver\n"
 	    "  -C  -dspdev file    use <file> as audio (oss) device\n"
 	    "      -vbidev file    use <file> as vbi device\n"
 	    "      -joydev file    use <file> as joystick device\n"
@@ -1612,7 +1711,7 @@ hello_world(char *name)
 	fprintf(stderr,"%s *must not* be installed suid root\n",name);
 	exit(1);
     }
-    
+
     uname(&uts);
     fprintf(stderr,"This is %s-%s, running on %s/%s (%s)\n",
 	    name,VERSION,uts.sysname,uts.machine,uts.release);
@@ -1640,11 +1739,12 @@ handle_cmdline_args(void)
 	args.dspdev = ng_dev.dsp;
     if (NULL == args.vbidev)
 	args.vbidev = ng_dev.vbi;
-    if (NULL == args.device) {
-	args.device = ng_dev.video;
-    } else {
+    if (args.device || args.driver)
 	args.xv_video = 0;
-    }
+    if (NULL == args.device)
+	args.device = "auto";
+    if (NULL == args.driver)
+	args.driver = ng_dev.driver;
     if (0 != args.xv_port)
 	args.xv_video = 1;
 }
@@ -1716,7 +1816,7 @@ vtx_to_tt(struct vt_page *vtp)
     struct fmt_page pg[1];
     struct fmt_char l[W+2];
 #define L (l+1)
-    
+
     t = 0;
     fmt_page(fmt,pg,vtp);
     memset(tt,0,sizeof(tt));
@@ -1741,21 +1841,21 @@ vtx_to_tt(struct vt_page *vtp)
 	    }
 	    L[x] = c;
 	}
-	
+
 	/* delay fg and attr changes as far as possible */
 	for (x = 0; x < W; ++x)
 	    if (L[x].ch == ' ') {
 		L[x].fg = L[x-1].fg;
 		L[x].attr = L[x-1].attr;
 	    }
-	
+
 	/* move fg and attr changes to prev bg change point */
 	for (x = W-1; x >= 0; x--)
 	    if (L[x].ch == ' ' && L[x].bg == L[x+1].bg) {
 		L[x].fg = L[x+1].fg;
 		L[x].attr = L[x+1].attr;
 	    }
-	
+
 	/* now render the line */
 	lcolor = -1;
 	tt[t].line = y;
@@ -1803,7 +1903,7 @@ tt_pick_subtitle(struct TEXTELEM *tt)
 	    i--;
 	tt[i].len = 0;
     }
-    
+
     return tt;
 }
 
@@ -1832,7 +1932,7 @@ x11_vbi_event(struct vbi_event *ev, void *user)
 {
     struct vbi_page pg;
     struct vbi_rect rect;
-    
+
     switch (ev->type) {
     case VBI_EVENT_NETWORK:
 	strcpy(x11_vbi_station,ev->ev.network.name);
@@ -1892,12 +1992,14 @@ int
 x11_vbi_tuned(void)
 {
 #if defined(__linux__)
-    struct video_tuner tuner;
+    struct v4l2_tuner tuner;
 
     if (NULL == x11_vbi)
 	return drv->is_tuned(h_drv);
-    memset(&tuner,0,sizeof(tuner));
-    if (-1 != ioctl(x11_vbi->fd,VIDIOCGTUNER,&tuner))
+
+    memset (&tuner, 0, sizeof(tuner));
+
+    if (-1 != ioctl(x11_vbi->fd, VIDIOC_G_TUNER, &tuner))
 	return tuner.signal ? 1 : 0;
 #endif
     return drv->is_tuned(h_drv);
@@ -2024,7 +2126,7 @@ void xt_kbd_init(Widget tv)
     list = cfg_list_entries("eventmap");
     if (NULL == list)
 	return;
-    
+
     for (; *list != NULL; list++) {
 	if (1 != sscanf(*list,"kbd-key-%31s",key))
 	    continue;
@@ -2054,7 +2156,7 @@ Pixmap bm_no;
 static unsigned char bm_yes_data[] = {
     /* -------- -------- */  0x00,
     /* -------- -------- */  0x00,
-    /* ------xx xx------ */  0x18,			   
+    /* ------xx xx------ */  0x18,
     /* ----xxxx xxxx---- */  0x3c,
     /* ----xxxx xxxx---- */  0x3c,
     /* ------xx xx------ */  0x18,
@@ -2068,19 +2170,17 @@ void
 create_pointers(Widget app_shell)
 {
     XColor white,red,dummy;
-    Screen *scr;
-    
+
     left_ptr = XCreateFontCursor(dpy,XC_left_ptr);
     menu_ptr = XCreateFontCursor(dpy,XC_right_ptr);
     qu_ptr   = XCreateFontCursor(dpy,XC_question_arrow);
-    scr = DefaultScreenOfDisplay(dpy);
     if (vinfo.depth > 1) {
 	if (XAllocNamedColor(dpy,colormap,"white",&white,&dummy) &&
 	    XAllocNamedColor(dpy,colormap,"red",&red,&dummy)) {
 	    XRecolorCursor(dpy,left_ptr,&red,&white);
 	    XRecolorCursor(dpy,menu_ptr,&red,&white);
 	    XRecolorCursor(dpy,qu_ptr,&red,&white);
-	} 
+	}
     }
 }
 
@@ -2127,7 +2227,7 @@ int xt_vm_randr_input_init(Display *dpy)
     if (debug)
 	fprintf(stderr,"xt: checking for vidmode extention ...\n");
     xfree_vm_init(dpy);
-    
+
     /* input */
     if (debug)
 	fprintf(stderr,"xt: checking for lirc ...\n");
@@ -2148,7 +2248,7 @@ int xt_vm_randr_input_init(Display *dpy)
 int xt_main_loop()
 {
     XEvent event;
-    
+
     if (debug)
 	fprintf(stderr,"xt: enter main event loop... \n");
     signal(SIGHUP,SIG_IGN); /* don't really need a tty ... */
